@@ -16,19 +16,23 @@
  *   except in compliance with the License. You may obtain a copy of
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
+
+/*
+ * This file is part of LibreOffice published API.
+ */
 #ifndef INCLUDED_COM_SUN_STAR_UNO_ANY_H
 #define INCLUDED_COM_SUN_STAR_UNO_ANY_H
 
-#include <sal/config.h>
+#include "sal/config.h"
 
 #include <cstddef>
 
-#include <rtl/ustring.hxx>
-#include <uno/any2.h>
-#include <typelib/typedescription.h>
-#include <cppu/unotype.hxx>
-#include <com/sun/star/uno/TypeClass.hdl>
-#include <rtl/alloc.h>
+#include "rtl/ustring.hxx"
+#include "uno/any2.h"
+#include "typelib/typedescription.h"
+#include "cppu/unotype.hxx"
+#include "com/sun/star/uno/TypeClass.hdl"
+#include "rtl/alloc.h"
 
 namespace com
 {
@@ -44,7 +48,7 @@ class Type;
 /** C++ class representing an IDL any.
     This class is used to transport any type defined in IDL. The class inherits from the
     binary C representation of uno_Any.
-    You can insert a value by either using the <<= operators or the template function makeAny().
+    You can insert a value by using the <<= operators.
     No any can hold an any. You can extract values from an any by using the >>= operators which
     return true if the any contains an assignable value (no data loss), e.g. the any contains a
     short and you >>= it into a long variable.
@@ -79,7 +83,11 @@ public:
 
 #if defined LIBO_INTERNAL_ONLY
     template<typename T1, typename T2>
-    explicit inline Any(rtl::OUStringConcat<T1, T2> const & value);
+    explicit inline Any(rtl::OUStringConcat<T1, T2> && value);
+    template<typename T1, typename T2>
+    explicit Any(rtl::OUStringConcat<T1, T2> const &) = delete;
+    template<typename T> explicit inline Any(rtl::OUStringNumber<T> && value);
+    template<typename T> explicit Any(rtl::OUStringNumber<T> const &) = delete;
 #endif
 
     /** Copy constructor: Sets value of the given any.
@@ -136,8 +144,8 @@ public:
     inline Any & SAL_CALL operator = ( const Any & rAny );
 
 #if defined LIBO_INTERNAL_ONLY
-    inline Any(Any && other);
-    inline Any & operator =(Any && other);
+    inline Any(Any && other) noexcept;
+    inline Any & operator =(Any && other) noexcept;
 #endif
 
     /** Gets the type of the set value.
@@ -166,7 +174,7 @@ public:
         @return the type class of the set value
      */
     TypeClass SAL_CALL getValueTypeClass() const
-        { return (TypeClass)pType->eTypeClass; }
+        { return static_cast<TypeClass>(pType->eTypeClass); }
 
     /** Gets the type name of the set value.
 
@@ -270,7 +278,7 @@ public:
         @return true if both any contains equal values
     */
     inline bool SAL_CALL operator == ( const Any & rAny ) const;
-    /** Unequality operator: compares two anys.
+    /** Inequality operator: compares two anys.
         The values need not be of equal type, e.g. a short integer is compared to a long integer.
 
         @param rAny another any (right side)
@@ -295,12 +303,13 @@ template<> bool Any::has<sal_uInt16>() const SAL_DELETED_FUNCTION;
 /// @endcond
 #endif
 
+#if !defined LIBO_INTERNAL_ONLY
 /** Template function to generically construct an any from a C++ value.
 
-    This can be useful with an explicitly specified template parameter, when the
+    @deprecated Just use an Any constructor with an appropriately typed argument.  (When the
     (UNO) type recorded in the Any instance shall be different from what would
-    be deduced from the (C++) type of the argument if no template parameter were
-    specified explicitly.
+    be deduced from the (C++) type of the argument, cast the argument to the appropriate type
+    first.)
 
     @tparam C value type
     @param value a value
@@ -309,16 +318,15 @@ template<> bool Any::has<sal_uInt16>() const SAL_DELETED_FUNCTION;
 template< class C >
 inline Any SAL_CALL makeAny( const C & value );
 
-#if !defined LIBO_INTERNAL_ONLY
 template<> inline Any SAL_CALL makeAny(sal_uInt16 const & value);
-#endif
 
 template<> Any SAL_CALL makeAny(Any const &) SAL_DELETED_FUNCTION;
+#endif
 
 /** Wrap a value in an Any, if necessary.
 
-    The difference to makeAny is that makeAny cannot be called on an Any, while
-    toAny just returns the given Any.
+    (A difference to the deprecated makeAny is that makeAny cannot be called on an Any, while
+    toAny just returns the given Any.)
 
     @since LibreOffice 5.0
 */
@@ -390,7 +398,7 @@ inline bool SAL_CALL operator >>= ( const Any & rAny, C & value );
 */
 template< class C >
 inline bool SAL_CALL operator == ( const Any & rAny, const C & value );
-/** Template unequality operator: compares set value of left side any to right side value.
+/** Template inequality operator: compares set value of left side any to right side value.
     The values need not be of equal type, e.g. a short integer is compared to a long integer.
     This operator can be implemented as template member function, if all supported compilers
     can cope with template member functions.
